@@ -4,7 +4,7 @@ from collections import OrderedDict
 import numpy as np
 import pandas as pd
 from sklearn.covariance import OAS
-from sklearn.decomposition import PCA
+from sklearn.decomposition import NMF, PCA
 from sklearn.discriminant_analysis import LinearDiscriminantAnalysis as LDA
 from sklearn.preprocessing import OneHotEncoder, OrdinalEncoder, StandardScaler
 from tqdm import tqdm
@@ -160,6 +160,17 @@ class FeatureTransformer:
 
                 temp = enc.fit_transform(pd.DataFrame(ds))
                 dim_red.fit(temp, label_enc)
+            elif self.ft_encoding == "nmf":
+                enc = OneHotEncoder(
+                    sparse=True,
+                    handle_unknown="infrequent_if_exist",
+                    max_categories=params["max_ohe_categories"],
+                    min_frequency=params["min_frequency"],
+                )
+                dim_red = NMF(n_components=params["nmf_n_components"])
+
+                temp = enc.fit_transform(pd.DataFrame(ds))
+                dim_red.fit(temp)
             else:
                 # Catboost needs categorical variables of type str/int, not float
                 enc = OrdinalEncoder(
@@ -256,9 +267,8 @@ class FeatureTransformer:
             )
             ret = extract_date_features(dt, ds_datetime_field)
         elif col_type == "categorical":
-            ret = pd.DataFrame(
-                self.enc[i].transform(pd.DataFrame(col_data)),
-            )
+            ret = self.enc[i].transform(pd.DataFrame(col_data))
+
             if self.ft_encoding:
                 ret = self.dim_red[i].transform(ret)
                 n_cols = ret.shape[1]
@@ -268,6 +278,7 @@ class FeatureTransformer:
                 ]
                 ret = pd.DataFrame(data=ret, columns=col_names)
             else:
+                ret = pd.DataFrame(ret)
                 ret.columns = [self.col_names[i]]
 
         return i, ret
